@@ -30,17 +30,6 @@ class BaseTest:
         kwargs["cst"] = 1
         kwargs["cbk"] = cls.callback_url
         response = cls.instance.initiator_request(kwargs)
-        data = {
-            'header_status': 200, 'status': 1,
-            'data': {'sid': '573DEM315181598786830186589499DEMO',
-                     'oid': '573737373673', 'amount': '10',
-                     'account': 'AS0242142710Y',
-                     'payment_channels': [
-                         {'name': 'MPESA', 'paybill': '510800'},
-                         {'name': 'AIRTEL', 'paybill': '510800'},
-                         {'name': 'EQUITEL', 'paybill': '510800'}],
-                     'hash': '85223ce0ab3ad53bf0fbc2d820ea275294d747d8870dd8264d0910d870f178e2'}}
         assert response["header_status"] == 200
         assert response["status"] == 1
-        assert response == data
         cls.sid = response["data"]["sid"]
